"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getItem = getItem;
exports.createItem = createItem;
exports.updateItem = updateItem;

var _first = _interopRequireDefault(require("lodash/first"));

var _constants = require("@instructure/quiz-common/lib/constants");

var _alerts = require("../../common/actions/alerts");

var _helpers = require("../../common/api/helpers");

var _Fetcher = _interopRequireDefault(require("../../common/util/Fetcher"));

var _callHandlers = require("../../common/api/callHandlers");

var _formatMessage = _interopRequireDefault(require("@instructure/quiz-common/lib/format-message"));

// =========================================
// =========================================
//  this file is in charge of coordinating
//  the dispatching of actions necessary
//  to interact with items via the api
// =========================================
// =========================================
// =====================
// =====================
//       CREATE
// =====================
// =====================
function getItem(itemId) {
  var url = "/api/items/".concat(itemId);
  return function (dispatch, getState) {
    var fetcher = new _Fetcher.default();
    return fetcher.get(url).then(function (itemData) {
      dispatch((0, _callHandlers.handleItemsResponse)([itemData]));
      return itemData;
    });
  };
}

function createItem(item, parentId, parentType) {
  var parentItemId = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;
  var resource = parentType === 'bank' ? 'banks' : 'quizzes';
  var url = "/api/".concat(resource, "/").concat(parentId, "/items");
  var itemParams = {
    feedback: item.feedback,
    interaction_data: item.interactionData,
    interaction_type_id: item.interactionType,
    item_body: item.itemBody,
    outcome_alignment_set_guid: item.outcomeAlignmentSetGuid,
    parent_item_id: parentItemId,
    properties: item.properties,
    scoring_algorithm: item.getScoringAlgorithm(),
    scoring_data: item.scoringData,
    title: item.title,
    user_response_type: (0, _first.default)(item.getInteractionType().userResponseTypeOptions),
    stimulus_id: item.stimulusId,
    calculator_type: item.calculatorType
  };
  var requestBody = JSON.stringify({
    item: itemParams
  });
  return function (dispatch, getState) {
    var errorMessage = (0, _formatMessage.default)('Failed to create item.');
    var fetcher = new _Fetcher.default({
      callType: _constants.CREATE_ITEM_CALL,
      onError: parentType === 'bank' ? (0, _helpers.handleError)(dispatch, errorMessage) : function () {
        return (0, _alerts.addError)(errorMessage);
      }
    });
    var createItemParams = {
      body: requestBody
    };
    return fetcher.post(url, createItemParams).then(function (itemData) {
      dispatch((0, _callHandlers.handleItemsResponse)([itemData]));
      return itemData;
    });
  };
} // =====================
// =====================
//       UPDATE
// =====================
// =====================


function updateItem(item, parentId, parentType) {
  var resource = parentType === 'bank' ? 'banks' : 'quizzes';
  var url = "/api/".concat(resource, "/").concat(parentId, "/items/").concat(item.id);
  var itemData = {
    item_body: item.itemBody,
    title: item.title,
    scoring_data: item.scoringData,
    scoring_algorithm: item.getScoringAlgorithm(),
    interaction_data: item.interactionData,
    properties: item.properties,
    outcome_alignment_set_guid: item.outcomeAlignmentSetGuid,
    feedback: item.feedback,
    calculator_type: item.calculatorType
  };
  var reqBody = JSON.stringify({
    item: itemData
  });
  return function (dispatch, getState) {
    var updateItemParams = {
      body: reqBody
    };
    var errorMessage = (0, _formatMessage.default)('Failed to update item.');
    var fetcher = new _Fetcher.default({
      callType: _constants.UPDATE_ITEM_CALL,
      onError: parentType === 'bank' ? (0, _helpers.handleError)(dispatch, errorMessage) : function () {
        return (0, _alerts.addError)(errorMessage);
      }
    });
    return fetcher.patch(url, updateItemParams).then(function (itemData) {
      dispatch((0, _callHandlers.handleItemsResponse)([itemData]));
      return itemData;
    });
  };
}